@@ -15,10 +15,8 @@
 # ------------------------------------------------------------------------------
 
 from pyasic.miners.backends import AntminerModern
-from pyasic.miners.types import HS3
+from pyasic.miners.device.models import HS3
 
 
 class BMMinerHS3(AntminerModern, HS3):
-    def __init__(self, ip: str, api_ver: str = "0.0.0"):
-        super().__init__(ip, api_ver)
-        self.supports_shutdown = False
+    supports_shutdown = False
