@@ -15,10 +15,8 @@
 # ------------------------------------------------------------------------------
 
 from pyasic.miners.backends import AntminerOld
-from pyasic.miners.types import Z15
+from pyasic.miners.device.models import Z15
 
 
 class CGMinerZ15(AntminerOld, Z15):
-    def __init__(self, ip: str, api_ver: str = "0.0.0"):
-        super().__init__(ip, api_ver)
-        self.supports_shutdown = False
+    supports_shutdown = False
