@@ -20,13 +20,16 @@ from pyasic.miners.device.models import (
     S19XP,
     S19a,
     S19aPro,
+    S19Hydro,
     S19i,
     S19j,
     S19jPro,
     S19kPro,
     S19NoPIC,
     S19Pro,
+    S19ProA,
     S19ProHydro,
+    S19XPHydro,
 )
 
 
@@ -42,10 +45,18 @@ class VNishS19Pro(VNish, S19Pro):
     pass
 
 
+class VNishS19Hydro(VNish, S19Hydro):
+    pass
+
+
 class VNishS19XP(VNish, S19XP):
     pass
 
 
+class VNishS19XPHydro(VNish, S19XPHydro):
+    pass
+
+
 class VNishS19a(VNish, S19a):
     pass
 
@@ -54,6 +65,10 @@ class VNishS19aPro(VNish, S19aPro):
     pass
 
 
+class VNishS19ProA(VNish, S19ProA):
+    pass
+
+
 class VNishS19i(VNish, S19i):
     pass
 
@@ -72,3 +87,7 @@ class VNishS19ProHydro(VNish, S19ProHydro):
 
 class VNishS19kPro(VNish, S19kPro):
     pass
+
+
+class VNishS19ProA(VNish, S19ProA):
+    pass
