@@ -13,9 +13,9 @@
 #  See the License for the specific language governing permissions and         -
 #  limitations under the License.                                              -
 # ------------------------------------------------------------------------------
-from pyasic.miners.backends import BFGMinerGoldshell
-from pyasic.miners.types import KDMax
+from pyasic.miners.backends import GoldshellMiner
+from pyasic.miners.device.models import KDMax
 
 
-class BFGMinerKDMax(BFGMinerGoldshell, KDMax):
+class GoldshellKDMax(GoldshellMiner, KDMax):
     pass
